# my_vk_bot/__init__.py

__version__ = '0.0.1'
__author__ = 'Ваше Имя'
__license__ = 'MIT'

# Импорт ключевых компонентов библиотеки
from dissentty_vk.api import VkAPI
from dissentty_vk.bot import VkBot

# Опциональная инициализация при импорте библиотеки
import logging

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)
logger.info(f"Библиотека {__name__} версии {__version__} инициализирована")


import vk_api
from vk_api.longpoll import VkLongPoll, VkEventType
from api import VkAPI

class VkBot:
    def __init__(self, token: str):
        self.api = VkAPI(token)
        self.vk_session = vk_api.VkApi(token=token)
        self.longpoll = VkLongPoll(self.vk_session)

    def listen(self):
        print("Бот запущен и слушает сообщения...")
        for event in self.longpoll.listen():
            if event.type == VkEventType.MESSAGE_NEW and event.to_me:
                self.process_message(event)

    def process_message(self, event):
        user_id = event.user_id
        message = event.text.lower()

        # Здесь можно реализовать логику ответа
        if message == "привет":
            self.api.send_message(user_id, "Привет! Как дела?")
        else:
            self.api.send_message(user_id, "Я не понял вашего сообщения.")


from setuptools import setup, find_packages

setup(
    name='bib_vk_bots',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        'vk-api',
    ],
    entry_points={
        'console_scripts': [
            'bib_vk_bots=bib_vk_bots.bot:main',
        ],
    },
)


import vk_api

class VkAPI:
    def __init__(self, token: str):
        self.vk_session = vk_api.VkApi(token=token)
        self.api = self.vk_session.get_api()

    def send_message(self, user_id: int, message: str):
        self.api.messages.send(user_id=user_id, message=message, random_id=0)